==> zio-aws-rds_3-5.17.128.1-sources.jar: zio/aws/rds/model/DescribeDbClustersResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribeDbClustersResponse(
    marker: scala.Option[String] = None,
    dbClusters: scala.Option[Iterable[zio.aws.rds.model.DBCluster]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbClustersResponse = {
    import DescribeDbClustersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbClustersResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        dbClusters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.dbClusters)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DescribeDbClustersResponse.ReadOnly =
    zio.aws.rds.model.DescribeDbClustersResponse.wrap(buildAwsValue())
}
object DescribeDbClustersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbClustersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeDbClustersResponse =
      zio.aws.rds.model.DescribeDbClustersResponse(
        marker.map(value => value),
        dbClusters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: scala.Option[String]
    def dbClusters: scala.Option[List[zio.aws.rds.model.DBCluster.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getDbClusters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.DBCluster.ReadOnly]] =
      AwsError.unwrapOptionField("dbClusters", dbClusters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbClustersResponse
  ) extends zio.aws.rds.model.DescribeDbClustersResponse.ReadOnly {
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
    override val dbClusters
        : scala.Option[List[zio.aws.rds.model.DBCluster.ReadOnly]] = scala
      .Option(impl.dbClusters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.DBCluster.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbClustersResponse
  ): zio.aws.rds.model.DescribeDbClustersResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rds_3-5.17.196.1-sources.jar: zio/aws/rds/model/DescribeDbClustersResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DescribeDbClustersResponse(
    marker: Optional[String] = Optional.Absent,
    dbClusters: Optional[Iterable[zio.aws.rds.model.DBCluster]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbClustersResponse = {
    import DescribeDbClustersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbClustersResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        dbClusters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.dbClusters)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DescribeDbClustersResponse.ReadOnly =
    zio.aws.rds.model.DescribeDbClustersResponse.wrap(buildAwsValue())
}
object DescribeDbClustersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbClustersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeDbClustersResponse =
      zio.aws.rds.model.DescribeDbClustersResponse(
        marker.map(value => value),
        dbClusters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: Optional[String]
    def dbClusters: Optional[List[zio.aws.rds.model.DBCluster.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getDbClusters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.DBCluster.ReadOnly]] =
      AwsError.unwrapOptionField("dbClusters", dbClusters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbClustersResponse
  ) extends zio.aws.rds.model.DescribeDbClustersResponse.ReadOnly {
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
    override val dbClusters
        : Optional[List[zio.aws.rds.model.DBCluster.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbClusters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.rds.model.DBCluster.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbClustersResponse
  ): zio.aws.rds.model.DescribeDbClustersResponse.ReadOnly = new Wrapper(impl)
}
